# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class Deploy(BaseModel):
    deploy: "DeployDeploy"


class DeployDeploy(BaseModel):
    id: UUID
    path: str


Deploy.model_rebuild()
DeployDeploy.model_rebuild()
