# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class ProteinConformer(BaseModel):
    protein_conformer: Optional["ProteinConformerProteinConformer"]


class ProteinConformerProteinConformer(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ProteinConformerProteinConformerData"]
    tags: List[str]


class ProteinConformerProteinConformerData(BaseModel):
    name: Optional[str]


ProteinConformer.model_rebuild()
ProteinConformerProteinConformer.model_rebuild()
ProteinConformerProteinConformerData.model_rebuild()
