# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Experiment(BaseModel):
    experiment: Optional["ExperimentExperiment"]


class ExperimentExperiment(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ExperimentExperimentData"]
    tags: List[str]


class ExperimentExperimentData(BaseModel):
    name: str
    unit: str
    measure: str
    value: float
    assay: str


Experiment.model_rebuild()
ExperimentExperiment.model_rebuild()
ExperimentExperimentData.model_rebuild()
