# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Protein(BaseModel):
    protein: Optional["ProteinProtein"]


class ProteinProtein(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["ProteinProteinData"]
    tags: List[str]


class ProteinProteinData(BaseModel):
    name: str
    sequence: str


Protein.model_rebuild()
ProteinProtein.model_rebuild()
ProteinProteinData.model_rebuild()
