# Generated by ariadne-codegen
# Source: combined.graphql

from datetime import datetime
from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class Smol(BaseModel):
    smol: Optional["SmolSmol"]


class SmolSmol(BaseModel):
    id: Any
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    deleted_at: Optional[datetime] = Field(alias="deletedAt")
    data: Optional["SmolSmolData"]
    tags: List[str]


class SmolSmolData(BaseModel):
    name: str
    inchi: str


Smol.model_rebuild()
SmolSmol.model_rebuild()
SmolSmolData.model_rebuild()
