# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmolTautomer(BaseModel):
    create_smol_tautomer: "CreateSmolTautomerCreateSmolTautomer"


class CreateSmolTautomerCreateSmolTautomer(BaseModel):
    id: Any


CreateSmolTautomer.model_rebuild()
CreateSmolTautomerCreateSmolTautomer.model_rebuild()
