# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProtein(BaseModel):
    create_protein: "CreateProteinCreateProtein"


class CreateProteinCreateProtein(BaseModel):
    id: Any


CreateProtein.model_rebuild()
CreateProteinCreateProtein.model_rebuild()
