# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class Retry(BaseModel):
    retry: "RetryRetry"


class RetryRetry(BaseModel):
    id: UUID


Retry.model_rebuild()
RetryRetry.model_rebuild()
