# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProject(BaseModel):
    create_project: "CreateProjectCreateProject"


class CreateProjectCreateProject(BaseModel):
    id: Any


CreateProject.model_rebuild()
CreateProjectCreateProject.model_rebuild()
