# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmolConformer(BaseModel):
    create_smol_conformer: "CreateSmolConformerCreateSmolConformer"


class CreateSmolConformerCreateSmolConformer(BaseModel):
    id: Any


CreateSmolConformer.model_rebuild()
CreateSmolConformerCreateSmolConformer.model_rebuild()
