# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateExperiment(BaseModel):
    create_experiment: "CreateExperimentCreateExperiment"


class CreateExperimentCreateExperiment(BaseModel):
    id: Any


CreateExperiment.model_rebuild()
CreateExperimentCreateExperiment.model_rebuild()
