# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateSmol(BaseModel):
    create_smol: "CreateSmolCreateSmol"


class CreateSmolCreateSmol(BaseModel):
    id: Any


CreateSmol.model_rebuild()
CreateSmolCreateSmol.model_rebuild()
