# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateStructure(BaseModel):
    create_structure: "CreateStructureCreateStructure"


class CreateStructureCreateStructure(BaseModel):
    id: Any


CreateStructure.model_rebuild()
CreateStructureCreateStructure.model_rebuild()
