# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateProteinConformer(BaseModel):
    create_protein_conformer: "CreateProteinConformerCreateProteinConformer"


class CreateProteinConformerCreateProteinConformer(BaseModel):
    id: Any


CreateProteinConformer.model_rebuild()
CreateProteinConformerCreateProteinConformer.model_rebuild()
