# Generated by ariadne-codegen
# Source: schema.graphql

from enum import Enum


class Element(str, Enum):
    H = "H"
    HE = "HE"
    LI = "LI"
    BE = "BE"
    B = "B"
    C = "C"
    N = "N"
    O = "O"
    F = "F"
    NE = "NE"
    NA = "NA"
    MG = "MG"
    AL = "AL"
    SI = "SI"
    P = "P"
    S = "S"
    CL = "CL"
    AR = "AR"
    K = "K"
    CA = "CA"
    SC = "SC"
    TI = "TI"
    V = "V"
    CR = "CR"
    MN = "MN"
    FE = "FE"
    CO = "CO"
    NI = "NI"
    CU = "CU"
    ZN = "ZN"
    GA = "GA"
    GE = "GE"
    AS = "AS"
    SE = "SE"
    BR = "BR"
    KR = "KR"
    RB = "RB"
    SR = "SR"
    Y = "Y"
    ZR = "ZR"
    NB = "NB"
    MO = "MO"
    TC = "TC"
    RU = "RU"
    RH = "RH"
    PD = "PD"
    AG = "AG"
    CD = "CD"
    IN = "IN"
    SN = "SN"
    SB = "SB"
    TE = "TE"
    I = "I"
    XE = "XE"
    CS = "CS"
    BA = "BA"
    LA = "LA"
    CE = "CE"
    PR = "PR"
    ND = "ND"
    PM = "PM"
    SM = "SM"
    EU = "EU"
    GD = "GD"
    TB = "TB"
    DY = "DY"
    HO = "HO"
    ER = "ER"
    TM = "TM"
    YB = "YB"
    LU = "LU"
    HF = "HF"
    TA = "TA"
    W = "W"
    RE = "RE"
    OS = "OS"
    IR = "IR"
    PT = "PT"
    AU = "AU"
    HG = "HG"
    TL = "TL"
    PB = "PB"
    BI = "BI"
    PO = "PO"
    AT = "AT"
    RN = "RN"
    FR = "FR"
    RA = "RA"
    AC = "AC"
    TH = "TH"
    PA = "PA"
    U = "U"
    NP = "NP"
    PU = "PU"
    AM = "AM"
    CM = "CM"
    BK = "BK"
    CF = "CF"
    ES = "ES"
    FM = "FM"
    MD = "MD"
    NO = "NO"
    LR = "LR"
    RF = "RF"
    DB = "DB"
    SG = "SG"
    BH = "BH"
    HS = "HS"
    MT = "MT"
    DS = "DS"
    RG = "RG"
    CN = "CN"
    NH = "NH"
    FL = "FL"
    MC = "MC"
    LV = "LV"
    TS = "TS"
    OG = "OG"


class MemUnits(str, Enum):
    B = "B"
    KB = "KB"
    MB = "MB"
    GB = "GB"
    TB = "TB"


class ModuleFailureReason(str, Enum):
    RESOLUTION = "RESOLUTION"
    DISPATCH = "DISPATCH"
    RUN = "RUN"
    STALLED = "STALLED"
    MISSING = "MISSING"
    CORRUPTED = "CORRUPTED"


class ModuleInstanceStatus(str, Enum):
    CREATED = "CREATED"
    RESOLVING = "RESOLVING"
    ADMITTED = "ADMITTED"
    DISPATCHED = "DISPATCHED"
    QUEUED = "QUEUED"
    RUNNING = "RUNNING"
    AWAITING_UPLOAD = "AWAITING_UPLOAD"
    COMPLETED = "COMPLETED"
    FAILED = "FAILED"
    CANCELLED = "CANCELLED"


class ModuleInstanceTarget(str, Enum):
    NIX = "NIX"
    GADI = "GADI"
    NIX_SSH = "NIX_SSH"
    NIX_SSH_2 = "NIX_SSH_2"
    NIX_SSH_3 = "NIX_SSH_3"
    NIX_SSH_4 = "NIX_SSH_4"
    SETONIX = "SETONIX"
    GADI_GPU = "GADI_GPU"
    NIX_SSH_GPU = "NIX_SSH_GPU"
    NIX_SSH_2_GPU = "NIX_SSH_2_GPU"
    NIX_SSH_3_GPU = "NIX_SSH_3_GPU"
    NIX_SSH_4_GPU = "NIX_SSH_4_GPU"
    SETONIX_GPU = "SETONIX_GPU"
    GADI_EXPRESS = "GADI_EXPRESS"
    SETONIX_EXPRESS = "SETONIX_EXPRESS"


class Order(str, Enum):
    ASC = "ASC"
    DESC = "DESC"


class OrderBy(str, Enum):
    ASC = "ASC"
    DESC = "DESC"
