# Generated by ariadne-codegen
# Source: combined.graphql

from uuid import UUID

from .base_model import BaseModel


class CancelModuleInstance(BaseModel):
    cancel: UUID


CancelModuleInstance.model_rebuild()
