# Generated by ariadne-codegen
# Source: combined.graphql

from typing import Any

from .base_model import BaseModel


class CreateEntity(BaseModel):
    create_entity: "CreateEntityCreateEntity"


class CreateEntityCreateEntity(BaseModel):
    id: Any


CreateEntity.model_rebuild()
CreateEntityCreateEntity.model_rebuild()
